# -*- coding: utf-8 -*-
# @Time    : 2018-12-18 17:44
# @Author  : play4fun
# @File    : DdkThemePromUrlGenerate.py
# @Software: PyCharm

"""
DdkThemePromUrlGenerate.py:
"""

from pdd_sdk.api.base import RestApi


class DdkThemePromUrlGenerate(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        self.pid = None  # 推广位
        self.theme_id_list = None  # 主题ID列表,例如[1,235]
        self.generate_short_url = None  # 是否生成短链接，true-是，false-否
        self.generate_mobile = None  # 是否生成手机跳转链接，true-是，false-否

        self.custom_parameters = None  # 自定义参数，为链接打上自定义标签。自定义参数最长限制64个字节。
        self.generate_weapp_webview = None  # 是否生成唤起微信客户端链接，true-是，false-否，默认false
        self.we_app_web_view_short_url = None  # 唤起微信app推广短链接
        self.we_app_web_wiew_url = None  # 唤起微信app推广链接
        # ?
        # self.generate_we_app: bool = None  # 是否生成小程序推广

    def getapiname(self):
        return 'pdd.ddk.theme.prom.url.generate'




from pdd_sdk.api.base import RestApi

class DdkGoodsRecommendGet(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        self.channel_type = 1  # 0-1.9包邮, 1-今日爆款, 2-品牌清仓,3-相似商品推荐,4-猜你喜欢,5-实时热销,6-实时收益,7-今日畅销,8-高佣榜单，默认1

        #自定义参数，为链接打上自定义标签；自定义参数最长限制64个字节；格式为： {"uid":"11111","sid":"22222"} ，其中 uid 用户唯一标识，可自行加密后传入，
        # 每个用户仅且对应一个标识，必填； sid 上下文信息标识，例如sessionId等，非必填。该json字符串中也可以加入其他自定义的key
        self.custom_parameters = None
        self.limit = 400    # 请求数量；默认值 ： 400
        self.list_id = "0"  #  翻页时建议填写前页返回的list_id值
        self.offset = 0 # 从多少位置开始请求；默认值 ： 0，offset需是limit的整数倍，仅支持整页翻页
        self.pid = None    # 推广位id

        # 猜你喜欢场景的商品类目，20100-百货，20200-母婴，20300-食品，20400-女装，20500-电器，20600-鞋包，20700-内衣，20800-美妆，20900-男装，
        # 21000-水果，21100-家纺，21200-文具,21300-运动,21400-虚拟,21500-汽车,21600-家装,21700-家具,21800-医药;
        self.cat_id = None
        self.goods_ids = None    # 相似商品推荐场景时必传。商品Id，请求相似商品时，仅取数组的第一位

    def getapiname(self):
        return 'pdd.ddk.goods.recommend.get'



# -*- coding: utf-8 -*-
# @Time    : 2018-12-09 14:27
# @Author  : play4fun
# @File    : DdkGoodsPromotionUrlGenerate.py
# @Software: PyCharm

"""
DdkGoodsPromotionUrlGenerate.py:
生成普通商品推广链接
"""

from pdd_sdk.api.base import RestApi


class DdkGoodsPromotionUrlGenerate(RestApi):
    def __init__(self, domain='gw-api.pinduoduo.com', port=80):
        RestApi.__init__(self, domain, port)
        # 自定义参数，为链接打上自定义标签；自定义参数最长限制64个字节；格式为： {"uid":"11111","sid":"22222"} ，
        # 其中 uid 用户唯一标识，可自行加密后传入，每个用户仅且对应一个标识，必填； sid 上下文信息标识，例如sessionId等，非必填。该json字符串中也可以加入其他自定义的key
        self.custom_parameters = None  

        
        self.generate_mall_collect_coupon = None # 布尔类型，是否生成店铺收藏券推广链接
        self.generate_qq_app = None # 布尔类型，是否生成qq小程序
        self.generate_schema_url = None # 布尔类型，是否返回 schema URL
        self.generate_short_url = None  # 布尔类型，是否生成短链接
        self.generate_weapp_webview = None  # 布尔类型，是否生成唤起微信客户端链接，true-是，false-否，默认false
        self.generate_weiboapp_webview = None # 布尔类型，是否生成微博推广链接
        self.generate_we_app = None # 布尔类型，是否生成小程序推广

        self.goods_id_list = None  # 商品ID，仅支持单个查询。例如：[123456]
        self.multi_group = None
        self.p_id = None  # 推广位id

        # true--生成多人团推广链接 false--生成单人团推广链接（默认false）1、单人团推广链接：用户访问单人团推广链接，可直接购买商品无需拼团。
        # 2、多人团推广链接：用户访问双人团推广链接开团，若用户分享给他人参团，则开团者和参团者的佣金均结算给推手
        self.multi_group = None  

        self.search_id = None  # 搜索id，建议填写，提高收益。来自pdd.ddk.goods.recommend.get、pdd.ddk.goods.search、pdd.ddk.top.goods.list.query等接口
        self.zs_duo_id = None  # 招商多多客ID

    def getapiname(self):
        return 'pdd.ddk.goods.promotion.url.generate'
